﻿* Encoding: windows-1252.
* MICS6 SR.5.3.

* v01 - 2017-09-21.

** Total weighted and unweighted numbers of children age 5-17 should be equal when normalized sample weights are used.

** The total weighted number of children age 5-17 does not necessarily match that presented on age groups 0-4 and 5-17 years in Table SR.4.1. 
** This table is based on completed children age 5-17 interviews only, whereas Table SR.4.1 is based on completed household interviews. The two tables are computed with different sample weights.


***.


* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = 'hl.sav'.

sort cases hh1 hh2 hl1.

save outfile='tmp.sav'
  /keep = hh1 hh2 hl1 hl14 hl4
  /rename = (hl1=ln).

* Open children data file.
get file = 'fs.sav'.

* sort cases in order to perform mergeing.
sort cases hh1 hh2 ln.

* merging with tmp file with mother's line number.
match files
 /file=*
 /table='tmp.sav'
 /by hh1 hh2 ln.

recode HL14 (sysmis = 0) (else = copy).
if (HL14 = FS4)  respondentToQ = 1.
if (HL14 ~= FS4) respondentToQ = 2.
if (FS4 = 90) respondentToQ = 3.

variable labels respondentToQ 'Respondent to the children age 5-17 questionnaire'.
value labels respondentToQ
  1 'Mother'
  2 'Other primary caretaker'
  3 'Emancipated [B]'.

* Select interviewed children.
select if (FS17 = 1).

* Weight the data by the 5-17 weight.
weight by fshweight.

* In order to add [A] in melevel label.
variable labels melevel "Mother’s education [A]".

* In order to add [B] in disability status.
variable labels fsdisability "Functional difficulties [C]".

variable labels caretakerdis "Mother's functional difficulties (age 18-49 years) [D]".

compute total = 1.
variable labels total "Total".
value labels total 1" ".

compute wp = 0.
variable labels wp " ".
compute numChildren = 0.
variable labels numChildren "Number of children age 5-17".

* Labels in French.
* variable labels respondentToQ 'Répondant du questionnaire enfant de 5-17 ans'.
* value labels respondentToQ
  1 'Mère'
  2 'Autre gardienne principale'
  3 'Emancipé [B]'.
 * variable labels melevel "Instruction de la mère [A]".
 * variable labels fsdisability "Difficultés fonctionnelles [C]".
 * variable labels caretakerdis "Difficultés fonctionnelles chez les méres (âge 18-49 ans) [D]".
 * variable labels numChildren "Nombre d'enfants de 5-17 ans".

* Labels in Spanish.
* variable labels respondentToQ 'Respondent to the children age 5-17 questionnaire'.
* value labels respondentToQ
  1 'Mother'
  2 'Other primary caretaker'
  3 'Emancipated [B]'.
 * variable labels melevel "Educación de la madre [A]".
 * variable labels fsdisability "Dificultades funcionales [C]".
 * variable labels caretakerdis "Dificultades funcionales de la madre (as de 18-49 años) [D]".
 * variable labels numChildren "Número niños/as de 5-17 años".


* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = wp display = none
  /table  total [c]
        + hl4 [c]
        + hh6 [c]
        + hh7 [c]
        + fsage [c]
        + melevel [c]
        + respondentToQ [c]
        + fsinsurance [c]
        + fsdisability [c]
        + caretakerdis [c]
        + ethnicity[c]
        + windex5[c]
   by
          wp [s] [colpct.count,'Weighted percent' f5.1]
        + numChildren [s] [count, 'Weighted', f5.0, 
                           ucount, 'Unweighted', f5.0]
  /categories variables=all empty=exclude missing = exclude
  /titles title =
     "Table SR.5.3: Children age 5-17's background characteristics"
     "Percent and frequency distribution of children age 5-17 by selected characteristics, " + surveyname
   caption =
            "[A] In this table and throughout the report where applicable, mother's education refers to educational attainment of mothers as well as caretakers of children age 5-17, " +
                    "who are the respondents to the children age 5-17 questionnaire if the mother is deceased or is living elsewhere. For emancipated children this is the education status of the selected child."		
            "[B] Children age 15-17 years were considered emancipated and individually interviewed if not living with his/her mother and the respondent to the Household Questionnaire indicated that the child does not have a primary caretaker."		
            "[C] The results of the Child Functioning module are presented in Chapter 11.1."			
            "[D] In this table and throughout the report, mother's functional difficulties refers to functional difficulty of mothers as well as caretakers of children age 5-17 as mentioned in note A. " +
                   "The category of 'No information' applies to mothers or caretakers to whom the Adult Functioning module was not administered, e.g. the mother is below age 18 or above age 49. " +
                   "Emancipated children are also included here. Please refer to Tables 8.1W and 8.1M for results of the Adult Functioning module.".


* Ctables command in French.
*
ctables
  /vlabels variables = wp display = none
  /table  total [c]
        + hl4 [c]
        + hh6 [c]
        + hh7 [c]
        + fsage [c]
        + melevel [c]
        + respondentToQ [c]
        + fsinsurance [c]
        + fsdisability [c]
        + caretakerdis [c]
        + ethnicity[c]
        + windex5[c]
   by
          wp [s] [colpct.count,'Pourcentage pondéré' f5.1]
        + numChildren [s] [count, 'Pondéré', f5.0, 
                           ucount, 'Non pondéré', f5.0]
  /categories variables=all empty=exclude missing = exclude
  /titles title =
     "Tableau SR.5.3: Caractéristiques de base des enfants de 5-17 ans"
     "Distribution en pourcentage et fréquence des enfants de 5-17 ans selon les caractéristiques de base sélectionnées, " + surveyname
   caption =
            "[A] Dans ce tableau et tout au long du rapport, l'éducation de la mère se réfère au niveau de scolarité des mères et des garidiennes des enfants de 5 à 17 ans, " +
                    "qui sont les répondants au questionnaire de 5-17 ans si la mère est décédée ou vit ailleurs . Pour les enfants émancipés, c'est le statut éducatif de l'enfant sélectionné."		
            "[B] Les enfants âgés de 15 à 17 ans étaient considérés émancipés et individuellement interrogés s'ils ne vivaient pas avec leur mère et le répondant au" +
                    "Questionnaire Ménage a indiqué que l'enfant n'avait pas de gardien principal."	
            "[C] Les résultats du module Fonctionnement de l'Enfant sont présentés au chapitre 11.1."			
            "[D] Dans ce tableau et tout au long du rapport, les difficultés fonctionnelles de la mère se réfèrent à la difficulté fonctionnelle des mères et " +
                    "des gardiennes d'enfants de 5 à 17 ans, comme mentionné dans la note A. La catégorie «Aucune information» s'applique aux mères ou gardiennes. " +
                    "le module n'a pas été administré, par exemple la mère a moins de 18 ans ou plus de 49 ans. Les enfants émancipés sont également inclus ici. " + 
                    "Veuillez vous référer aux tableaux 8.1W et 8.1M pour les résultats du module Fonctionnement des adultes.".	

* Ctables command in Spanish.
*
ctables
  /vlabels variables = wp display = none
  /table  total [c]
        + hl4 [c]
        + hh6 [c]
        + hh7 [c]
        + fsage [c]
        + melevel [c]
        + respondentToQ [c]
        + fsinsurance [c]
        + fsdisability [c]
        + caretakerdis [c]
        + ethnicity[c]
        + windex5[c]
   by
          wp [s] [colpct.count,'Porcentaje ponderado' f5.1]
        + numChildren [s] [count, 'Ponderado', f5.0, 
                           ucount, 'Sin ponderar', f5.0]
  /categories variables=all empty=exclude missing = exclude
  /titles title =
     "Tabla SR.5.3: Características básicas de niños/as de 5-17 años"
     "Distribución porcentual y frecuencial de niños/as de 5-17 años por características seleccionadas, " + surveyname
   caption =
            "[A]  En esta tabla y a través de todo el reporte, la educación de la madre se refiere a los logros en materia educativa de las madres así como las cuidadoras de los niños/as de 5-17 años, " +
                    "quienes son los respondientes del cuestionario de 5-17 años si la madre ha fallecido o vive fuera del hogar. Para niños emancipados sería el estatus educacional del niño seleccionado. "		
            "[B] Los niños de 15-17 años se conciderarán emancipados y se entrevistarán individualmente si no vive con la madre y el respondiente al cuestionario del hogar informa que no tiene un cuidador primario."	
            "[C] Los resultados del módulo de capacidad funcional se presentan en el Capítulo 11.1."			
            "[D]  En esta tabla y en todo el informen, las dificultades funcionales de la madre se refieren a las dificultades funcionales de la madre así como " +
                    "a los cuidadores de los niños 5-17 años como se menciona en la nota A. La categoría «Sin información» aplica a las madres o cuidadores a las cuales " +
                    "no se les pudo administrar el módulo de Funcionamiento en adultos, es decir la madre es menor de 18 o mayor de 49 años. " + 
                    "Consulte en las Tablas 8.1W y 8.1M los resultados del módulo de Funcionamiento en Adultos.".	

new file.

erase file = 'tmp.sav'.
