﻿* Encoding: windows-1252.
* MICS6 SR.9.3W.

* v01 - 2017-09-22.
* v02 - 2019-03-14.

** The table consists of three panels, one for each of computer, mobile phone and internet use.

** Respondents who have ever used a computer are those responding yes to MT4. Those that used in the last 3 months are those responding 1, 2 or 3 in MT5 and those using at least once a week are MT5=2 or 3.

** Ownership of mobile phone: MT11=1. Similar to current use of computers, the use of mobile phone in the last 3 months is MT12=1, 2 or 3 and those using at least weekly are MT12=2 or 3.

** Ever use of internet is MT9=1 or MT6[C]=1 or MT6[F]=1. Similar to above, the current use is captured through MT10.


***.


* Call include file for the working directory and the survey name.
include "surveyname.sps".

* Open women dataset.
get file = 'wm.sav'.

include "CommonVarsWM.sps".

* Select completed interviews.
select if (WM17 = 1).

* Weight the data by the women weight.
weight by wmweight.

* Generate numWomen variable.
compute numWomen = 1.
variable labels numWomen "".
value labels numWomen 1 "Number of women".

* Generate indicators.
* Respondents who have ever used a computer are those responding yes to MT4. Those that used in the last 3 months are those responding 1, 2 or 3 in MT5 and those using at least once a week are MT5=2 or 3.
recode MT4 (1 = 100) (else = 0) into compev.
variable labels compev "Ever".

recode MT5 (1, 2, 3= 100) (else = 0) into comp3.
variable labels comp3 "During the last 3 months [1]".

recode MT5 (2, 3 = 100) (else = 0) into comp1w.
variable labels comp1w "At least once a week during the last 3 months".

* Ownership of mobile phone: MT11=1. Similar to current use of computers, the use of mobile phone in the last 3 months is MT12=1, 2 or 3 and those using at least weekly are MT12=2 or 3.
recode MT11 (1 = 100) (else = 0) into mobile.
variable labels mobile "Own a mobile phone [2]".

recode MT12 (1, 2, 3= 100) (else = 0) into mobile3.
variable labels mobile3 "During the last 3 months [3]".

recode MT12 (2, 3 = 100) (else = 0) into mobile1w.
variable labels mobile1w "At least once a week during the last 3 months".

* Ever use of internet is MT9=1 or MT6[C]=1 or MT6[F]=1. Similar to above, the current use is captured through MT10.
recode MT9 (1 = 100) (else = 0) into intev.
if (MT6C = 1 or MT6F = 1) intev = 100.
variable labels intev "Ever".

recode MT10 (1, 2, 3 = 100) (else = 0) into int3.
variable labels int3 "During the last 3 months [4]".

recode MT10 (2, 3 = 100) (else = 0) into int1w.
variable labels int1w "At least once a week during the last three months [5]".

compute layer0 = 0.
variable labels layer0 "".
value labels layer0 0 "Percentage of women who:".

compute layer1 = 0.
variable labels layer1 "".
value labels layer1 0 "Used a computer".

compute layer2 = 0.
variable labels layer2 "".
value labels layer2 0 "Used a mobile phone".

compute layer3 = 0.
variable labels layer3 "".
value labels layer3 0 "Used internet".

compute total = 1.
variable labels total "".
value labels total 1 "Total".

* Labels in French.
* value labels numWomen 1 "Nombre de femmes âgées de 15 à 49 ans".
* variable labels compev "Déjà".
* variable labels comp3 "Durant les 3 derniers mois [1]".
* variable labels comp1w "Au moins une fois par semaine durant les 3 derniers mois".
* variable labels mobile "Posséder un téléphone mobile [2]".
* variable labels mobile3 "Durant les 3 derniers mois [3]".
* variable labels mobile1w "Au moins une fois par semaine durant les 3 derniers mois".
* variable labels intev "Déjà".
* variable labels int3 "Durant les 3 derniers mois [4]".
* variable labels int1w "Au moins une fois par semaine durant les 3 derniers mois [5]".
* value labels layer0 0 "Pourcentage d'hommes de 15-49 ans qui:".
* value labels layer1 0 "Déjà utilisé un ordinateur".
* value labels layer2 0 "Utilisé un téléphone portable".
* value labels layer3 0 "Utilisé Internet".

* Labels in Spanish.
* value labels numWomen 1 "Número de mujeres de 15-49 años".
* variable labels compev "Alguna vez".
* variable labels comp3 "Durante los últimos 3 meses [1]".
* variable labels comp1w "Al menos una vez a la semana durante los últimos 3 meses".
* variable labels mobile "Posee un teléfono móvil [2]".
* variable labels mobile3 "Usaron un teléfono móvil [3]".
* variable labels mobile1w "Al menos una vez a la semana durante los últimos 3 meses".
* variable labels intev "Alguna vez".
* variable labels int3 "Durante los últimos 3 meses [4]".
* variable labels int1w "Al menos una vez a la semana durante los últimos 3 meses [5]".
* value labels layer0 0 "Porcentaje de hombres de 15-49 años que:".
* value labels layer1 0 "Usaron una computadora".
* value labels layer2 0 "Usaron un teléfono móvil".
* value labels layer3 0 "Usaron internet".

ctables
  /vlabels variables =  numWomen layer0 layer1 layer2 layer3 total
         display = none
  /table   total [c]
        + hh6 [c]
        + hh7 [c]
        + $wage [c]
        + welevel [c]
        + disability [c]
        + ethnicity [c]
        + windex5 [c]
      by
           layer0 [c] > ( layer1 [c] > (compev [s] [mean '' f5.1]
                        + comp3 [s] [mean '' f5.1]
                        + comp1w [s] [mean '' f5.1])
                        + mobile [s] [mean '' f5.1]
                        + layer2 [c] > (mobile3 [s] [mean '' f5.1]
                        + mobile1w [s] [mean '' f5.1])
                        + layer3 [c] > (intev [s] [mean '' f5.1]
                        + int3 [s] [mean '' f5.1]
                        + int1w [s] [mean '' f5.1] ))
         + numWomen[c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Table SR.9.3W: Use of ICT (women)"
     "Percentage of women age 15-49 years who have ever used a computer, the internet and who own a mobile phone, " +
     "percentage who have used during the last 3 months and percentage who have used at least once weekly during the last three months, "
     + surveyname
   caption =
        "[1] MICS indicator SR.9 - Use of computer"
        "[2] MICS indicator SR.10 - Ownership of mobile phone; SDG indicator 5.b.1"												
        "[3] MICS indicator SR.11 - Use of mobile phone"									
        "[4] MICS indicator SR.12a - Use of internet (during the last 3 months); SDG indicator 17.8.1"												
        "[5] MICS indicator SR.12b - Use of internet (at least once a week during the last 3 months)".								
											

* Ctables in French.
* ctables
  /vlabels variables =  numWomen layer0 layer1 layer2 layer3 total
         display = none
  /table   total [c]
        + hh6 [c]
        + hh7 [c]
        + $wage [c]
        + welevel [c]
        + disability [c]
        + ethnicity [c]
        + windex5 [c]
      by
           layer0 [c] > ( layer1 [c] > (compev [s] [mean '' f5.1]
                        + comp3 [s] [mean '' f5.1]
                        + comp1w [s] [mean '' f5.1])
                        + mobile [s] [mean '' f5.1]
                        + layer2 [c] > (mobile3 [s] [mean '' f5.1]
                        + mobile1w [s] [mean '' f5.1])
                        + layer3 [c] > (intev [s] [mean '' f5.1]
                        + int3 [s] [mean '' f5.1]
                        + int1w [s] [mean '' f5.1] ))
         + numWomen[c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tableau SR.9.3W:  Utilisation d' IOT (femmes)"
     "Pourcentage de femmes de 15-49 ans qui ont déjà utilisé un ordinateur et Internet, et qui possèdent un téléphone mobile, " +
     "pourcentage qui ont utilisé au cours des 3 derniers mois et pourcentage qui ont utilisé au moins une fois par semaine au cours des 3 derniers mois, "
     + surveyname
   caption =
        "[1] Indicateur MICS SR.9 - Utilisation d’ordinateurs "
        "[2] Indicateur MICS SR.10 - Propriété du téléphone mobile; SDG indicater 5.b.1"												
        "[3] Indicateur MICS SR.11 - L'utilisation du téléphone mobile"									
        "[4] Indicateur MICS SR.12a - Utilisation d'Internet (durant les 3 derniers mois); SDG indicateur 17.8.1"												
        "[5] Indicateur MICS SR.12b - Utilisation d'Internet (au moins une fois par semaine durant les 3 derniers mois)".

* Ctables in Spanish.
* ctables
  /vlabels variables =  numWomen layer0 layer1 layer2 layer3 total
         display = none
  /table   total [c]
        + hh6 [c]
        + hh7 [c]
        + $wage [c]
        + welevel [c]
        + disability [c]
        + ethnicity [c]
        + windex5 [c]
      by
           layer0 [c] > ( layer1 [c] > (compev [s] [mean '' f5.1]
                        + comp3 [s] [mean '' f5.1]
                        + comp1w [s] [mean '' f5.1])
                        + mobile [s] [mean '' f5.1]
                        + layer2 [c] > (mobile3 [s] [mean '' f5.1]
                        + mobile1w [s] [mean '' f5.1])
                        + layer3 [c] > (intev [s] [mean '' f5.1]
                        + int3 [s] [mean '' f5.1]
                        + int1w [s] [mean '' f5.1] ))
         + numWomen[c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tabla SR.9.3W: Uso de TIC (mujeres)"
     "Porcentaje de mujeres de 15-49 años que han usado una computadora e internet y que poseen un teléfono móvil, " +
	 "porcentaje que los han usado durante los últimos 3 meses, y porcentaje que los han usado al menos una vez a la semana durante los últimos 3 meses, "
     + surveyname
   caption =
        "[1] Indicador MICS SR.9 - Uso de computadora"
        "[2] Indicador MICS SR.10 - Propiedad de teléfono móvil; indicador ODS 5.b.1"												
        "[3] Indicador MICS SR.11 - Uso de teléfono móvil"									
        "[4] Indicador MICS SR.12a - Uso de internet (durante los últimos 3 meses; indicador ODS 17.8.1"												
        "[5] Indicador MICS SR.12b - Uso de internet (al menos una vez a la semana durante los últimos 3 meses)".
		
new file.


