* Encoding: windows-1252.
***.
*v1. 2019-03-14.

include "surveyname.sps".

get file = 'wm.sav'.

include "CommonVarsWM.sps".

select if (WM17 = 1).

weight by wmweight.

* definitions of contraceptiveMethod .
include 'define\MICS6 - 06 - TM.sps' .

select if  (mstatus <> 1 and sexact = 1).

compute layer = 0.
variable labels layer "".
value labels layer 0 "Percentage of sexually active [A] women currently unmarried or not in union who are using (or whose partner is using):".

compute anyModern = 0.
if (contraceptiveMethod >= 1 and contraceptiveMethod <= 11) anyModern = 100.
variable labels anyModern "Any modern method".

compute anyTraditional = 0.
if (contraceptiveMethod >= 12 and contraceptiveMethod < 99) anyTraditional = 100.
variable labels anyTraditional "Any traditional method".

* Any method of contraception still includes all responses to CP3, i.e. all modern and traditional methods, as well as any missing values (CP3 = A-X or ?). 
compute anyMethod = 0.
if (anyModern = 100 or anyTraditional = 100 or contraceptiveMethod = 99) anyMethod = 100.
variable labels anyMethod "Any method".

compute livingChildren = 0.
if (CM1 = 1 and CM8 <> 1) livingChildren = CM11.
if (CM1 = 1 and CM8 = 1) livingChildren = CM11 - (CM9 + CM10).
recode livingChildren (0 thru 3 = copy) (4 thru hi = 4).
variable labels livingChildren "Number of living children".
value labels livingChildren 4 "4+".
formats livingChildren (f5.0).

compute numWomen = 1.
variable labels numWomen "Number of sexually active [A] women currently unmarried or not in union".
value labels numWomen 1 "".

variable labels disability "Functional difficulties (age 18-49 years)".

compute total = 1.
variable labels total "Total".
value labels total 1" ".

*  For labels in French uncomment commands below.
* variable labels
     numWomen "Nombre de femmes sexuellement actives [A] femmes actuellement non maries ou pas en union"
	/livingChildren "Nombre d'enfants vivants"
	/anyModern "N'importe quelle mthode moderne"
	/anyTraditional "N'importe quelle mthode traditionnelle"
	/anyMethod "N'importe quelle mthode [1]"
	/disability "Difficults fonctionnelles (ge 18-49 ans)".
   
*  For labels in Spanish uncomment commands below.
* variable labels
     numWomen "Nmero de mujeres sexualmente activas [A] actualmente no casadas o en unin"
	/livingChildren "Nmero de hijos vivos"
	/anyModern "Cualquier mtodo moderno"
	/anyTraditional "Cualquier mtodo tradicional"
	/anyMethod "Cualquier mtodo [1]"
	/disability "Dificultades funcionales (18-49 aos de edad)".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /table   total [c]
         + HH6 [c]
         + hh7 [c]
         + $wage [c]
         + welevel [c]
         + livingChildren [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]            
   by    
         layer [c] > (   
         anyModern [s] [mean '' f5.1]
         + anyTraditional [s] [mean '' f5.1]
         + anyMethod [s] [mean '' f5.1])
         + numWomen [s] [sum '' f5.0]
  /categories variables=all empty=exclude missing=exclude         
  /slabels position=column visible = no
  /titles title=
     "Table TM.3.2: Use of contraception (currently unmarried/not in union)"
     "Percentage of sexually active women age 15-49 years currently unmarried or not in union who are using (or whose partner is using) a contraceptive method, " + surveyname
   caption=
     "[A] >>Sexually active<< is defined as having had sex within the last 30 days."
  .													

* Ctables command in French.
* ctables
  /table   total [c]
         + HH6 [c]
         + hh7 [c]
         + $wage [c]
         + welevel [c]
         + livingChildren [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]            
   by    
         layer [c] > (      
         anyModern [s] [mean '' f5.1]
         + anyTraditional [s] [mean '' f5.1]
         + anyMethod [s] [mean '' f5.1])
         + numWomen [s] [sum '' f5.0]
  /categories variables=all empty=exclude missing=exclude                 
  /slabels position=column visible = no
  /titles title=
     "Tableau TM.3.2:  Utilisation de la contraception (Actuellement non mari / pas en union)"
     "Pourcentage de femmes de 15-49 ans actuellement maries ou en union qui utilisent (ou dont le conjoint utilise) une mthode de contraception, " + surveyname
   caption=
     "[A] >>Sexuellement actif<< est dfini comme ayant eu des relations sexuelles au cours des 30 derniers jours."
  .		

* Ctables command in Spanish.
* ctables
  /table   total [c]
         + HH6 [c]
         + hh7 [c]
         + $wage [c]
         + welevel [c]
         + livingChildren [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]            
   by    
         layer [c] > (      
         anyModern [s] [mean '' f5.1]
         + anyTraditional [s] [mean '' f5.1]
         + anyMethod [s] [mean '' f5.1])
         + numWomen [s] [sum '' f5.0]
  /categories variables=all empty=exclude missing=exclude                 
  /slabels position=column visible = no
  /titles title=
     "Tabla TM.3.2: Uso de anticonceptivos (actualente no casadas/en unin)"
     "Porcentaje de mujeres sexualmente activas de 15-49 aos actuanlente no casada ni en unin que estn usando (o cuya pareja est usando) un mtodo anticonceptivo, " + surveyname
   caption=
     "[A] >>Sexualmente activa<< se define como que ha tenido relaciones sexuales en los ltimos 30 das."
  .	  

new file.
