﻿* Encoding: windows-1252.
***.

*v2. 2019-03-14.

include "surveyname.sps".

get file = 'wm.sav'.

include "CommonVarsWM.sps".

select if (WM17 = 1).

weight by wmweight.

*select women that gave birth in two years preceeding the survey.
select if (CM17 = 1).

* definitions of anc, ageAtBirth .
include 'define\MICS6 - 06 - TM.sps' .

* Health check following birth while in facility or while at home.
compute healthCheck = 0.
if (PN4 = 1 or PN8 = 1) healthCheck = 100.
variable labels healthCheck "Health check following birth while in facility or at home [A]".

compute pncCheck = 0.
if (healthCheck = 100 or (pncVisitC = 1 or pncVisitC = 2 or pncVisitC = 3)) pncCheck = 100.
variable labels pncCheck "Post-natal health check for the newborn [1] [C]".

compute numBirths = 1.
variable labels numBirths "Number of  women with a live birth in the last 2 years ".
value labels numBirths 1 "".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

variable labels pncVisitC "PNC visit for newborns [B]".

variable labels welevel "Education".
variable labels ageAtBirth "Age at most recent live birth".
variable labels disability "Functional difficulties (age 18-49 years)".

* For labels in French uncomment commands below.
* variable labels
     healthCheck "Examen de santé après la naissance dans le centre de santé ou à la maison [A]"
	/pncCheck "Examens post-natals pour nouveaux-nés [1], [C]"
	/pncVisitC "Visites de EPN pour nouveau-nés [B]"
	/numBirths "Nombre de dernières naissances vivantes dans les 2 dernières années "
	/welevel "Mother’s education"
	/ageAtBirth "Mother’s age at delivery"
	/disability "Mother's functional disabilities (age 18-49 years)".
	
* For labels in Spanish uncomment commands below.
* variable labels
     healthCheck "Revisión de salud inmediatamente después del nacimiento en el centro de salud o en la casa [A]"
	/pncCheck "Revisión de salud post-natal para el recién nacido [1], [C]"
	/pncVisitC "Vista CPN para recién nacidos [B]"
	/numBirths "Número de últimos nacimientos vivos en los últimos dos años"
	/welevel "Mother’s education"
	/ageAtBirth "Mother’s age at delivery"
	/disability "Mother's functional disabilities (age 18-49 years)".
 
* Ctables command in English (currently active, comment it out if using different language).
ctables
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]           
   by
           healthCheck [s] [mean '' f5.1]
         + pncVisitC [c] [rowpct.validn '' f5.1]
         + pncCheck [s] [mean '' f5.1]
         + numBirths[s] [count '' f5.0]
  /categories variables=all empty=exclude
  /categories variables=pncVisitC total=yes label='Total'
  /slabels position=column visible=no
  /titles title=
	"Table TM.8.2: Post-natal health checks for newborns"
	"Percentage of women age 15-49 years with a live birth in the last 2 years whose most recent live-born child received health checks while in facility or at home following birth, " +
                   "percent distribution who received post-natal care (PNC) visits from any health provider after birth, by timing of visit, and percentage who received post-natal health checks,  "								
	 + surveyname
  caption=
     "[1] MICS indicator TM.13 - Post-natal health check for the newborn"									
     "[A] Health checks by any health provider following facility births (before discharge from facility) or following home births (before departure of provider from home)."									
     "[B] Post-natal care visits (PNC) refer to a separate visit by any health provider to check on the health of the newborn and provide preventive care services. " +
     "PNC visits do not include health checks following birth while in facility or at home (see note a above). " 								
     "[C] Post-natal health checks include any health check performed while in the health facility or at home following birth (see note a above), as well as PNC visits (see note b above) within two days of delivery.".

* Ctables command in French.
* ctables
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]           
   by
           healthCheck [s] [mean '' f5.1]
         + pncVisitC [c] [rowpct.validn '' f5.1]
         + pncCheck [s] [mean '' f5.1]
         + numBirths[s] [count '' f5.0]
  /categories variables=all empty=exclude
  /categories variables=pncVisitC total=yes label='Total'
  /slabels position=column visible=no
  /titles title=
	"Tableau TM.8.2: Examens de santé post-natals des nouveau-nés"
	"Pourcentage de femmes de 15-49 ans ayant eu une naissance vivante dans les 2 dernières années dont la dernière naissance a reçu des examens de santé dans le centre de santé ou à la maison après la naissance, "+
	"distribution en pourcentage de celles dont la dernière naissance vivante a reçu ue visite pour des examens post-natals (EPN) par n'importe quel agent de santé après la naissance, " +
                  "selon le moment de la visite et pourcentage de qui a reçu des examens de santé post-natals,  "								
	 + surveyname
  caption=
     "[1] Indicateur MICS TM.13 - Examens de santé post-natal pour nouveau-nés"									
     "[A] Des bilans de santé effectués par tout prestataire de soins après les accouchements (avant la sortie de l'établissement) ou après les accouchements à domicile (avant le départ du prestataire de la maison)."									
     "[B] Les visites de soins postnatales (PNC) se réfèrent à une visite séparée par un prestataire de santé pour vérifier la santé du nouveau-né et fournir des services de soins préventifs. " +
	 "Les visites de la PNC n'incluent pas les bilans de santé après la naissance dans l'établissement ou à la maison (voir la note a au dessus)." 								
     "[C] Les bilans de santé postnatals incluent tous les bilans de santé effectués dans l'établissement de santé ou à la maison après la naissance (voir note a ci-dessus), " +
     "ainsi que les visites PNC (voir note b ci-dessus) dans les deux jours suivant l'accouchement.".

* Ctables command in Spanish.
* ctables
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]           
   by
           healthCheck [s] [mean '' f5.1]
         + pncVisitC [c] [rowpct.validn '' f5.1]
         + pncCheck [s] [mean '' f5.1]
         + numBirths[s] [count '' f5.0]
  /categories variables=all empty=exclude
  /categories variables=pncVisitC total=yes label='Total'
  /slabels position=column visible=no
  /titles title=
	"Tabla TM.8.2: Revisiones post-natales para el recién nacido "
	"Porcentaje de mujeres de 15-49 años con un nacido vivo en los últimos dos años cuyo último nacido vivo recibió controles de salud en el centro de salud o en la casa inmediatamente después del nacimiento, " +
	"distribución porcentual cuyo último nacido vivo recibió visitas de cuidado post-natal (CPN)  de algún proveedor de salud después del nacimiento, por el momento de la visita, y porcentaje que recibió revisiones de salud post natales,  "								
	 + surveyname
  caption=
     "[1] Indicador MICS TM.13 - Chequeos post-natales para el recién nacido"									
     "[A] Controles de salud realizados por cualquier proveedor de servicios de salud después de nacimientos en el centro de atención (antes del alta de la instalación) " +
     "o después de partos en el hogar (antes de la salida del proveedor de la casa)."									
     "[B] Las visitas de atención postnatal (CPN) se refieren a una visita por separado de cualquier proveedor de salud para controlar la salud del recién nacido y brindar servicios de atención preventiva. " +
     "Las visitas a la CPN no incluyen controles de salud posteriores al nacimiento mientras se encuentran en el centro o en el hogar (consulte la nota A)."
     "[C] Los controles de salud postnatales incluyen cualquier revisión de salud realizada en el centro de salud o en el hogar después del nacimiento (ver nota A), " +
     "así como las visitas a la CPN (ver nota B arriba) dentro de los dos días posteriores al parto.".

new file.
