* Encoding: windows-1252.
* MICS6 TC-7.7.

 * The 7 food groups as listed above are distributed here:.
 * 1) Breastmilk: BD3=1
2) Grains, roots, and tubers: BD8[B], BD8[C], and BD8[E]
3) Legumes and nuts: BD8[M]
4) Dairy products: BD7[D], BD7[E], BD8[A], and BD8[N]
5) Flesh foods: BD8[I], BD8[J], and BD8[L]
6) Eggs: BD8[K]
7) Vitamin A rich fruits and vegetables: BD8[D], BD8[F], and BD8[G]
8) Other fruits and vegetables: BD8[H]

 * Minimum dietary diversity:
Children who received food from at least 5 of the 8 groups listed above.

 * Minimum meal frequency:
Currently breastfed: 
  i) Age 6-8 months: Solid, semi-solid, or soft foods at least two times (BD11>=2)
 ii) Age 9-23 months: Solid, semi-solid, or soft foods at least three times (BD11>=3)
Currently not breastfed: Solid, semi-solid, soft, or milk feeds at least four times: (BD7[D]N+BD7[E]N+BD11 >= 4)

 * Currently not breastfed children who received at least 2 milk feeds:
(BD7[D]N+BD7[E]N+BD8[A]N >= 2)

 * Minimum acceptable diet:
Currently breastfed:
Children who received the minimum dietary diversity and the minimum meal frequency as defined above.
 * Currently not breastfed:
Children who received the minimum meal frequency, at least 2 milk feeds, and the minimum dietary diversity (as defined above, with the exception that food group 4 is limited to just BD8[N] to avoid double-counting).

 * Note that the algorithms presented here are for illustrative purposes only and do not take the full programming into account, e.g. dealing with "Don't know" responses.

***.

* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = 'ch.sav'.

include "CommonVarsCH.sps".

select if (UF17 = 1).

weight by chweight.

select if (cage >= 6 and cage <= 23).

* Recode system missing and missing to zero, even the variable is one digit 7 is 7+ not Incositent, so 7 is not included.
recode BD7D1 BD7E1 BD8A1 BD9
  (sysmis, 8, 9 = 0) .

* Generate indicators.
recode BD3 (sysmis, 8, 9 = 2) .
* Minimum dietary diversity.
 * The 8 food groups as listed above are distributed here:.
 * 1) Breastmilk: BD3=1
2) Grains, roots, and tubers: BD8[B], BD8[C], and BD8[E]
3) Legumes and nuts: BD8[M]
4) Dairy products: BD7[D], BD7[E], BD8[A], and BD8[N]
5) Flesh foods: BD8[I], BD8[J], and BD8[L]
6) Eggs: BD8[K]
7) Vitamin A rich fruits and vegetables: BD8[D], BD8[F], and BD8[G]
8) Other fruits and vegetables: BD8[H].

compute breastmilk= any(1, BD3) .
compute grainsRootsTubers = any(1, BD8B, BD8C, BD8E) .
compute legumesNuts = any(1, BD8M) .
compute dairyProducts = any(1, BD7D, BD7E, BD8A, BD8N) .
compute fleshFoods = any(1, BD8I, BD8J, BD8L) .
compute eggs = any(1, BD8K) .
compute vitaminA = any(1, BD8D, BD8F, BD8G) .
compute other = any(1, BD8H) .

* Children who received food from at least 5 of the 8 groups listed above.
compute minimumDietaryDiversity = sum(breastmilk, grainsRootsTubers, legumesNuts, dairyProducts, fleshFoods, eggs, vitaminA, other) >= 5 .

* Adjusted minimum dietary diversity (as defined above, with the exception that food group 3 is limited to just BD8[N]) for non breastfed children.
 * do if (BD3 = 1).
 * + compute dairyProductsAdj = any(1, BD7D, BD7E, BD8A, BD8N) .
 * else .
 * + compute dairyProductsAdj = any(1,                   BD8N) .
 * end if.

do if (BD3<> 1).
+compute minimumDietaryDiversityAdj = sum(grainsRootsTubers, legumesNuts, fleshFoods, eggs, vitaminA, other) >= 4 .
end if.

* Minimum meal frequency .

*Currently breastfed.
do if (BD3 = 1) .
* Age 6-8 months: Solid, semi-solid, or soft foods at least two times (BD9>=2).
+ do if (cage >= 6 and cage <= 8).
+   compute minimumMealFrequency = BD9>=2 .
* Age 9-23 months: Solid, semi-solid, or soft foods at least three times (BD9>=3).
+ else .
+   compute minimumMealFrequency = BD9>=3 .
+ end if.
*Currently not breastfed.
else .
* Solid, semi-solid, soft, or milk feeds at least four times: (BD7[D]1+BD7[E]1+BD9 >= 4).
+ compute minimumMealFrequency = BD7D1+BD7E1+BD9 >= 4 .
* Currently not breastfed children who received at least 2 milk feeds.
* (BD7[D]1+BD7[E]1+BD8[A]1 >= 2).
+ compute atLeast2MilkFeeds = BD7D1+BD7E1+BD8A1 >= 2 .
end if.

* Minimum acceptable diet .
* Currently breastfed.
do if (BD3 = 1) .
* Children who received the minimum dietary diversity and the minimum meal frequency as defined above.
+ compute minimumAcceptableDiet = minimumDietaryDiversity & minimumMealFrequency .
* Currently not breastfed.
else .
* Children who received the minimum meal frequency, at least 2 milk feeds, 
* and the minimum dietary diversity (as defined above, with the exception that food group 3 is limited to just BD8[N]).
+ compute minimumAcceptableDiet = minimumDietaryDiversityAdj & minimumMealFrequency & atLeast2MilkFeeds.
end if .

compute childrenNo = 1.
variable labels childrenNo "Number of children age 6-23 months".
value labels childrenNo 1 "".

compute layerAll = 1.
do if (BD3 = 1).
+ compute layerBreastefed = 1.
else .
+ compute layerNotBreastefed = 1.
end if.

compute layerPercent  = 1.
compute total = 1.

variable labels layerAll ""
  /layerBreastefed ""
  /layerNotBreastefed ""
  /layerPercent ""
  /total "Total" .

value labels layerAll 1 "All"
  /layerBreastefed 1 "Currently breastfeeding"
  /layerNotBreastefed 1 "Currently not breastfeeding"
  /layerPercent 1 "Percent of children who received:"
  /total 1 " " .

* multiplay by 100 to obtain percents .
compute minimumDietaryDiversity = 100 * minimumDietaryDiversity .
compute minimumMealFrequency    = 100 * minimumMealFrequency .
compute minimumAcceptableDiet   = 100 * minimumAcceptableDiet .
compute atLeast2MilkFeeds       = 100 * atLeast2MilkFeeds .


* For labels in French uncomment commands below.
* variable labels
    ageCat "Age (en mois)"
   /childrenNo "Nombre d'enfants de 6-23 mois".
* value labels 
   layerAll 1 "Tous"
  /layerBreastefed 1 "Actuellement allaits "
  /layerNotBreastefed 1 "Actuellement non allaits "
  /layerPercent 1 "Pourcentage d'enfants qui ont reu :".
     
* For labels in Spanish uncomment commands below.
* variable labels
    ageCat "Edad (en meses)"
   /childrenNo "Nmero de nios de 6-23 meses".
* value labels 
   layerAll 1 "Todos"
  /layerBreastefed 1 "Lactancia actualmente"
  /layerNotBreastefed 1 "Sin lactancia actualmente "
  /layerPercent 1 "Porcentaje de nios que recibieron:".


* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = layerAll layerBreastefed layerNotBreastefed layerPercent
                       minimumDietaryDiversity minimumMealFrequency minimumAcceptableDiet 
                       atLeast2MilkFeeds childrenNo
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + ageCatz [c]
         + melevel [c]
         + caretakerdis[c]
         + windex5 [c]
   by
           layerBreastefed [c] > (
             layerPercent [c] > (
               minimumDietaryDiversity[s][mean, "Minimum dietary diversity [A]" ,f5.1]
             + minimumMealFrequency   [s][mean, "Minimum meal frequency [B]" ,f5.1]
             + minimumAcceptableDiet  [s][mean, "Minimum acceptable diet [1] [C]" ,f5.1] )
           + childrenNo [s][validn,'Number of children age 6-23 months',f5.0] )
         + layerNotBreastefed [c] > (
             layerPercent [c] > (
               minimumDietaryDiversity[s][mean, "Minimum dietary diversity [A]" ,f5.1]
             + minimumMealFrequency   [s][mean, "Minimum meal frequency [B]" ,f5.1]
             + minimumAcceptableDiet  [s][mean, "Minimum acceptable diet [2] [C]" ,f5.1]
             + atLeast2MilkFeeds      [s][mean, "At least 2 milk feeds [3]" ,f5.1] )
           + childrenNo [s][validn,'Number of children age 6-23 months',f5.0] )
         + layerAll [c] > (
             layerPercent [c] > (
               minimumDietaryDiversity[s][mean, "Minimum dietary diversity [4] [A]" ,f5.1]
             + minimumMealFrequency   [s][mean, "Minimum meal frequency [5] [B]" ,f5.1]
             + minimumAcceptableDiet  [s][mean, "Minimum acceptable diet [C]" ,f5.1] )
           + childrenNo [s][validn,'Number of children age 6-23 months',f5.0] )
  /categories variables=all empty=exclude missing=exclude
  /titles title=
     "Table TC.7.7: Infant and young child feeding (IYCF) practices"
     "Percentage of children age 6-23 months who received appropriate liquids and solid, semi-solid, or soft foods " +
     "the minimum number of times or more during the previous day, by breastfeeding status, " + surveyname
  caption=
     "[1] MICS indicator TC.39a - Minimum acceptable diet (breastfed children)"
     "[2] MICS indicator TC.39b - Minimum acceptable diet (non-breastfed children)"
     "[3] MICS indicator TC.40 - Milk feeding frequency for non-breastfed children"
     "[4] MICS indicator TC.41 - Minimum dietary diversity"
     "[5] MICS indicator TC.42 - Minimum meal frequency"
     "[A] Minimum dietary diversity is defined as receiving foods from at least 5 of 8 food groups: 1) breastmilk, 2) grains, roots and tubers, 3) legumes " 
          "and nuts, 4) dairy products (milk, infant formula, yogurt, cheese), 5) flesh foods (meat, fish, poultry and liver/organ meats), 6) eggs, 7) vitamin-A "
          "rich fruits and vegetables, and 8) other fruits and vegetables."															
     "[B] Minimum meal frequency among currently breastfeeding children is defined as children who also received solid, semi-solid, or soft foods "
          "2 times or more daily for children age 6-8 months and 3 times or more daily for children age 9-23 months. For non-breastfeeding children "
          "age 6-23 months it is defined as receiving solid, semi-solid or soft foods, or milk feeds, at least 4 times."
     "[C] The minimum acceptable diet for breastfed children age 6-23 months is defined as receiving the minimum dietary diversity and the "
          "minimum meal frequency, while it for non-breastfed children further requires at least 2 milk feedings and that the minimum dietary "
          "diversity is achieved without counting milk feeds." .

		  
* Ctables command in French.
* ctables
  /vlabels variables = layerAll layerBreastefed layerNotBreastefed layerPercent
                       minimumDietaryDiversity minimumMealFrequency minimumAcceptableDiet 
                       atLeast2MilkFeeds childrenNo
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + ageCatz [c]
         + melevel [c]
         + caretakerdis[c]
         + ethnicity [c]
         + windex5 [c]
   by
           layerBreastefed [c] > (
             layerPercent [c] > (
               minimumDietaryDiversity[s][mean, "Diversit alimentaire minimale [A]" ,f5.1]
             + minimumMealFrequency   [s][mean, "Frquence minimum de repas [B]" ,f5.1]
             + minimumAcceptableDiet  [s][mean, "Rgime alimentaire minimum acceptable [1] [C]" ,f5.1] )
           + childrenNo [s][validn,'Nombre d'enfants de 6-23 mois',f5.0] )
         + layerNotBreastefed [c] > (
             layerPercent [c] > (
               minimumDietaryDiversity[s][mean, "Diversit alimentaire minimale [A]" ,f5.1]
             + minimumMealFrequency   [s][mean, "Frquence minimum de repas [B]" ,f5.1]
             + minimumAcceptableDiet  [s][mean, "Rgime alimentaire minimum acceptable [2] [C]" ,f5.1]
             + atLeast2MilkFeeds      [s][mean, "Au moins 2 repas lacts [3]" ,f5.1] )
           + childrenNo [s][validn,'Nombre d'enfants de 6-23 mois',f5.0] )
         + layerAll [c] > (
             layerPercent [c] > (
               minimumDietaryDiversity[s][mean, "Diversit alimentaire minimale [4] [A]" ,f5.1]
             + minimumMealFrequency   [s][mean, "Frquence minimum de repas [5] [B]" ,f5.1]
             + minimumAcceptableDiet  [s][mean, "Rgime alimentaire minimum acceptable [C]" ,f5.1] )
           + childrenNo [s][validn,'Nombre d'enfants de 6-23 mois',f5.0] )
  /categories variables=all empty=exclude missing=exclude
  /titles title=
     "Tableau TC.7.7: Pratiques alimentaires des nourrissons et jeunes enfants (IYCF)"
     "Pourcentage d'enfants de 6-23 mois qui ont reu des liquides et des aliments solides, semi-solides ou mous le nombre minimum de fois ou "+
	 "plus durant le jour prcdent, selon le statut d'allaitement,  " + surveyname
  caption=
     "[1] Indicateur MICS TC.39a - Rgime alimentaire minimum acceptable (allaits)"
     "[2] Indicateur MICS TC.39b - Rgime alimentaire minimum acceptable (non allaits)"
     "[3] Indicateur MICS TC.40 - Frquence de repas lacts pour les enfants non allaits"
     "[4] Indicateur MICS TC.41 - Diversit alimentaire minimum"
     "[5] Indicateur MICS TC.42 - Frquence minimum de repas"
     "[A]  La diversit alimentaire minimum est dfinie comme recevoir des aliments d'au moins 4 des 7 groupes d'aliments : 1) Graines, racines et tubercules, 2) lgumes et noix, "+
	 "3) produits laitiers (lait, yaourts, fromage), 4) aliments carns (viande, poisson, volaille et foie/abats), 5) oeufs, 6) fruits et lgumes riches en vitamine A et 7) autres fruits et lgumes."															
     "[B] La frquence minimum de repas parmi les enfants actuellement allaits est dfinie comme les enfants qui ont aussi reu des aliments solides, semi-solides ou mous 2 fois ou plus par jour pour les enfants de 6-8 mois "+
	 "et 3 fois par jour pour les enfants de 9-23 mois. Pour les enfants de 6-23 mois non allaits actuellement, ceci est dfini comme recevoir des aliments solides, semi-solides ou mous ou des aliments lacts au moins 4 fois."
     "[C] Le rgime alimentaire minimum acceptable pour les enfants allaits de 6-23 mois est dfini comme recevoir la diversit alimentaire minimum et la frquence minimum de repas, alors que pour les enfants qui ne sont pas allaits, "+
	 "il faut rajouter au moins 2 repas lacts et il faut que la diversit alimentaire minum soit atteinte sans compter les repas lacts. " .

* Ctables command in Spanish.
* ctables
  /vlabels variables = layerAll layerBreastefed layerNotBreastefed layerPercent
                       minimumDietaryDiversity minimumMealFrequency minimumAcceptableDiet 
                       atLeast2MilkFeeds childrenNo
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + ageCatz [c]
         + melevel [c]
         + caretakerdis[c]
         + ethnicity [c]
         + windex5 [c]
   by
           layerBreastefed [c] > (
             layerPercent [c] > (
               minimumDietaryDiversity[s][mean, "Diversidad alimentaria mnima [A]" ,f5.1]
             + minimumMealFrequency   [s][mean, "Frecuencia mnima de comidas [B]" ,f5.1]
             + minimumAcceptableDiet  [s][mean, "Dieta mnima aceptable [1] [C]" ,f5.1] )
           + childrenNo [s][validn,'Nmero de nios de 6-23 meses',f5.0] )
         + layerNotBreastefed [c] > (
             layerPercent [c] > (
               minimumDietaryDiversity[s][mean, "Diversidad alimentaria mnima [A]" ,f5.1]
             + minimumMealFrequency   [s][mean, "Frecuencia mnima de comidas [B]" ,f5.1]
             + minimumAcceptableDiet  [s][mean, "Dieta mnima aceptable [2] [C]" ,f5.1]
             + atLeast2MilkFeeds      [s][mean, "Al menos 2 alimentaciones de leche [3]" ,f5.1] )
           + childrenNo [s][validn,'Nmero de nios de 6-23 meses',f5.0] )
         + layerAll [c] > (
             layerPercent [c] > (
               minimumDietaryDiversity[s][mean, "Diversidad alimentaria mnima [4] [A]" ,f5.1]
             + minimumMealFrequency   [s][mean, "Frecuencia mnima de comidas [5] [B]" ,f5.1]
             + minimumAcceptableDiet  [s][mean, "Dieta mnima aceptable [C]" ,f5.1] )
           + childrenNo [s][validn,'Nmero de nios de 6-23 meses',f5.0] )
  /categories variables=all empty=exclude missing=exclude
  /titles title=
     "Tabla TC.7.7: Prcticas de alimentacin de infantes y nios pequeos "
     "Porcentaje de nios de 6-23 meses que recibieron apropiadamente lquidos y slidos, o alimentos suaves el nmero mnimo de veces o ms durante el da previo, por estado de lactancia, " + surveyname
  caption=
     "[1] MICS indicador TC.39a - Alimentacin mnima aceptable (nios/as amamantados)"
     "[2] MICS indicador TC.39b - Alimentacin mnima aceptable (nios/as no amamantados)"
     "[3] MICS indicador TC.40 - Frecuencia de alimentacin con leche para los nios que no son amamantados"
     "[4] MICS indicador TC.41 - Diversidad alimentaria mnima"
     "[5] MICS indicador TC.42 - Frecuencia de alimentacin mnima"
     "[A] La diversidad alimentaria mnima se define como recibir alimentos de al menos 5 de 8 grupos alimenticios: "+
	 "1) leche materna, 2) granos, races y tubrculos, 3) legumbres y nueces, 4) productos lcteos (leche, frmula infantil, yogur, queso), "+
	 "5) alimentos crnicos (carne, pescado, carne de ave e hgado / carne de rganos), 6) huevos, 7) frutas y verduras ricas en vitamina A, y 8) otras frutas y verduras."															
     "[B] Frecuencia mnima de comida entre nios actualmente en lactancia es definida como aquellos nios que tambin reciben "+
	 "alimentos slidos, semislidos o suaves, o alimentos suaves 2 veces o ms al da para nios de 6-8 meses y 3 veces o ms al da para nios de 9-23 meses. "+
	 "Para nios no lactantes de 6-23 meses es definida como recibir alimentos slidos, semislidos o suaves, o al menos 4 tomas de leche."
     "[C] Dieta mnima aceptable para nios lactantes de 6-23 meses es definida como recibir la diversidad alimentaria mnima y la frecuencia mnima de comida, "+
	 "mientras que sta para nios no lactantes adems requiere al menos 2 tomas de leche y que la diversidad alimentaria mnima se alcance sin la cuenta de tomas de leche." .		  

new file.
