* Encoding: windows-1252.

include "surveyname.sps".

get file = 'hl.sav'.

weight by hhweight.

include "define/MICS6 - 08 - LN.sps".

* Select children who are attending first grade of primary education regardless of age.
select if (schage = primarySchoolEntryAge - 1).

compute numChildren = 1.
variable labels numChildren  "".
value labels numChildren 1 "Number of children age 5 years at the beginning of the school year".

compute ecd  = 0.
if (ED10a = 0) ecd =  100.
variable labels ecd "Attending an early childhood education programme".

compute primary  = 0.
if (ED10a = 1) primary =  100.
variable labels primary "Attending primary education".

compute notattending = 0.
if (ecd = 0 and primary = 0) notattending = 100.
variable labels notattending "Not attending an early childhood education programme or primary education".

compute attendance = 0.
if (ecd = 100 or primary = 100) attendance = 100.
variable labels attendance "Net attendance ratio [1]".

compute layer = 0.
variable labels layer "".
value labels layer 0 "Percentage of children:".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

compute tot = 100.
variable labels tot "Total".

*  For labels in French uncomment commands below.
* variable labels
     attendance "Taux net de scolarisation [1]"
	/notattending "Ne pas participer  un programme d'ducation de la petite enfance ou  l'enseignement primaire"
	/primary "Assister  l'enseignement primaire"
	/ecd "Assister  un programme d'ducation de la petite enfance".
* value labels 
     layer 0 "Pourcentage d'enfants: "
    /numChildren 1 "Nombre d'enfants gs de 5 ans au dbut de l'anne scolaire" .
    
*  For labels in Spanish uncomment commands below.
* variable labels
     attendance "Tasa neta de asistencia [1]"
	/notattending "No asisten a un programa de educacin de la primera infancia ni a primaria"
	/primary "Asisten a la primaria"
	/ecd "Asisten a un programa de educacin de la primera infancia".
* value labels 
     layer 0 "Porcentaje de nios/as que: "
    /numChildren 1 "Nmero de nios de 5 aos al comienzo del ao escolar" .

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables =  numChildren layer
           display = none 
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
           layer [c]> (ecd [s] [mean '' f5.1] + primary [s] [mean '' f5.1] + notattending [s] [mean '' f5.1]) + tot [s] [mean '' f5.1] + attendance [s] [mean '' f5.1] + numChildren [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
    "Table LN.1.2: Participation rate in organised learning"					
    "Percent distribution of children age one year younger than the official primary school entry age at the beginning of the school year, " +
     "by attendance to education, and attendance to an early childhood education programme or primary education (adjusted net attendance ratio), " + surveyname
   caption=
    "[1] MICS indicator LN.2 - Participation rate in organised learning (adjusted); SDG indicator 4.2.2"
  .

  * Ctables command in French.  
* ctables
  /vlabels variables =  numChildren layer
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
           layer [c]> (ecd [s] [mean '' f5.1] + primary [s] [mean '' f5.1] + notattending [s] [mean '' f5.1]) + tot [s] [mean '' f5.1] + attendance [s] [mean '' f5.1] + numChildren [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
    "Tabla LN.1.2: Tasa de participacin en la enseanza organizada "					
    "Distribucin porcentual de nios/as un ao menores que la edad oficial de ingreso a la escuela primaria al comienzo del ao escolar, " +
     "por asistencia a la escuela y asistencia a un programa de educacin de la primera infancia o de educacin primaria (razn de asistencia neta ajustada), " + surveyname
   caption=
    "[1] MICS indicador LN.2 - Tasa de participacin en la enseanza organizada (ajustada); Indicador ODS 4.2.2 "
  .

    * Ctables command in Spanish.  
* ctables
  /vlabels variables =  numChildren layer
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
          layer [c]> (ecd [s] [mean '' f5.1] + primary [s] [mean '' f5.1] + notattending [s] [mean '' f5.1]) + tot [s] [mean '' f5.1] + attendance [s] [mean '' f5.1] + numChildren [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
    "Tabla LN.1.2: Tasa de participacin en la enseanza organizada "					
    "Distribucin porcentual de nios/as un ao menores que la edad oficial de ingreso a la escuela primaria al comienzo del ao escolar, " +
     "por asistencia a la escuela y asistencia a un programa de educacin de la primera infancia o de educacin primaria (razn de asistencia neta ajustada), " + surveyname
   caption=
    "[1] MICS indicador LN.2 - Tasa de participacin en la enseanza organizada (ajustada); Indicador ODS 4.2.2 "
  .

new file.
