* Encoding: windows-1252.

* The table presents three indicators, one of which may require customisation: MICS Indicator LN.22b is measured on children with age for primary grades 2 and 3. 
* Following the standard used throughout the standard LN tables, 
* the indicator is set age age 7 and 8, as children start school at age 6. 
* For example, if primary grade 1 is set at age 7 in a country, this indicator should instead be measured on age group 8-9.

include "surveyname.sps".

get file = 'fs.sav'.

weight by fsweight.

*The denominator includes all children with a completed module (FL28=01).
select if (FL28 = 1).

select if CB3 >=7 and CB3 <=14.

 * Percentage of children who:
- Read 90% of words in a story correctly: FL19>=90%
- Correctly answer three literal comprehension questions: FL22 [A]=1 and FL22 [B]=1 and FL22 [C]=1
- Correctly answer two inferential comprehension questions: FL22 [D]=1 and FL22 [E]=1
- Demonstrate foundational reading skills: All of the above.

do if (FL7 = 1 or FL9 = 1).
count target =  FL19W1  FL19W2  FL19W3  FL19W4  FL19W5  FL19W6  FL19W7  FL19W8  FL19W9 FL19W10
               FL19W11 FL19W12 FL19W13 FL19W14 FL19W15 FL19W16 FL19W17 FL19W18 FL19W19 FL19W20
               FL19W21 FL19W22 FL19W23 FL19W24 FL19W25 FL19W26 FL19W27 FL19W28 FL19W29 FL19W30 
               FL19W31 FL19W32 FL19W33 FL19W34 FL19W35 FL19W36 FL19W37 FL19W38 FL19W39 FL19W40
               FL19W41 FL19W42 FL19W43 FL19W44 FL19W45 FL19W46 FL19W47 FL19W48 FL19W49 FL19W50
               FL19W51 FL19W52 FL19W53 FL19W54 FL19W55 FL19W56 FL19W57 FL19W58 FL19W59 FL19W60
               FL19W61 FL19W62 FL19W63 FL19W64 FL19W65 FL19W66 FL19W67 FL19W68 FL19W69 FL19W70 
               FL19W71  (' ').
end if.

recode target (sysmis = 0) (else = copy).

* Replace 72 below with total number of words in your survey.
compute readCorrect = 0.
if (target >= 0.9 * 71) readCorrect = 100.
variable labels readCorrect " ".

compute aLiteral = 0.
if (FL22A=1 and FL22B=1 and FL22C=1) aLiteral = 100.
variable labels aLiteral " ".

compute aInferential = 0.
if (FL22D=1 and FL22E=1) aInferential = 100.
variable labels aInferential " ".

compute readingSkill = 0.
if (readCorrect = 100 and aLiteral = 100 and aInferential = 100) readingSkill = 100.
variable labels readingSkill " ".
	
compute numChildren = 1.
variable labels numChildren " ".
value labels numChildren 1 " ".	

recode CB8A (0=0)(1=10)(2=20)(3,4 = 30) (8,9 = 99)(else = 100) into school.
variable labels school "School attendance".
value labels school
0 "Early childhood education"
10 "Primary"
20 "Lower secondary"
30 "Upper secondary +"
99 "DK/Missing"
100 "Out-of-school".

compute schoolAux = school.
if ((CB8A = 1 or CB8A = 2) and CB8B < 97)  schoolAux1 = school + CB8B.
if ((CB8A = 1 or CB8A = 2) and CB8B >= 97) schoolAux1 = 99.
if (CB8A = 1 and (CB8B = 2 or CB8B = 3)) schoolAux2 = 11.1.

value labels schoolAux
0      "Early childhood education"
10    "Primary"
11     "  Grade 1"
11.1  "  Grade 2-3 [3]"
12     "    Grade 2"
13     "    Grade 3"
14     "  Grade 4"
15     "  Grade 5"
16     "  Grade 6"
20    "Lower secondary"
21     "  Grade 1"
22     "  Grade 2"
23     "  Grade 3"
30     "Upper secondary +"
99     "DK/Missing"
100   "Out-of-school".

* Define Multiple Response Sets.
mrsets
  /mcgroup name = $school
           label = 'School attendance'
           variables = schoolAux schoolAux1 schoolAux2.

compute schageAux = schage.
if (schage = 7 or schage = 8) schageAux1 = 6.1.

value labels schageAux
 6    "6"
 6.1 "7-8 [2]"
 7    "   7"
 8    "   8"
 9    "9"
 10  "10"
 11  "11"
 12  "12"
 13  "13"
 14  "14".

* Define Multiple Response Sets.
mrsets
  /mcgroup name = $schage
           label = 'Age at beginning of school year'
           variables = schageAux schageAux1.

* Only the total pane includes the column "Percentage of children for whom the reading book was not available in appropriate language". 
* The algorithm for this is: (CB7/ED9=1 and FL9>3) or (CB7/ED9=2 or blank and FL7>3). 
* Note the categories accepted for FL9 and FL7 are those for which no reading book was available). 
* This must be customised in syntax.
compute notAvailable = 0.
if (FL7 <> 1 and FL9 <> 1) notAvailable = 100.
variable labels notAvailable "Percentage of children for whom the reading book was not available in appropriate language".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".	

compute tot = 1.
variable labels tot "".
value labels tot 1 "Total".

compute layer = 0.
variable labels layer "".
value labels layer 0 "Percentage who correctly answered comprehension questions".		

*  For labels in French uncomment commands below.
* Define Multiple Response Sets.
* mrsets
  /mcgroup name = $school
           label = 'Frquentation scolaire'
           variables = schoolAux schoolAux1 schoolAux2.
* mrsets
  /mcgroup name = $schage
           label = "Age au dbut de l'anne scolaire"
           variables = schageAux schageAux1.
* compute layer = 0.
* variable labels layer "".
* value labels layer 0 "Pourcentage ayant rpondu correctement aux questions de comprhension".	
* value labels school
0 "Prescolaire"
10 "Primaire"
20 "Secondaire 1er Cycle"
30 "Secondaire 2eme Cycle +"
99 "NSP/Manquant"
100 "En dehors de l'cole".
* value labels schoolAux
0      "Prescolaire"
10    "Primaire"
11     "  Niveau 1"
11.1  "  Niveau 2-3 [3]"
12     "    Niveau 2"
13     "    Niveau 3"
14     "  Niveau 4"
15     "  Niveau 5"
16     "  Niveau 6"
20    "Secondaire 1er Cycle"
21     "  Niveau 1"
22     "  Niveau 2"
23     "  Niveau 3"
30     "Secondaire 2eme Cycle +"
99     "NSP/Manquant"
100   "En dehors de l'cole".

*  For labels in Spanish uncomment commands below.
* Define Multiple Response Sets.
* mrsets
  /mcgroup name = $school
           label = 'Asistencia a la escuela'
           variables = schoolAux schoolAux1 schoolAux2.
* mrsets
  /mcgroup name = $schage
           label = "Edad al inicio del ao escolar"
           variables = schageAux schageAux1.
* compute layer = 0.
* variable labels layer "".
* value labels layer 0 "Porcentaje que respondi correctamente las preguntas de comprensin".	
* value labels school
0 "Educacin de la primera  infancia"
10 "Primaria"
20 "Secundaria baja"
30 "Secundaria alta +"
99 "NS/Ignorado"
100 "Fuera de la escuela".
* value labels schoolAux
0      "Educacin de la primera  infancia"
10    "Primaria"
11     "  Grado 1"
11.1  "  Grado 2-3 [3]"
12     "    Grado 2"
13     "    Grado 3"
14     "  Grado 4"
15     "  Grado 5"
16     "  Grado 6"
20    "Secundaria baj"
21     "  Grado 1"
22     "  Grado 2"
23     "  Grado 3"
30     "Secundaria alta +"
99     "NS/Ignorado"
100   "Fuera de la escuela".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /format missing = "na" 
  /vlabels variables = numChildren readCorrect aLiteral aInferential readingSkill notAvailable HL4 tot layer
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + $schage [c]
         + $school [c]
         + melevel [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
   by
          hl4 [c] > (readCorrect [s] [mean,'Percentage who correctly read 90% of words in a story',f5.1] + 
                       layer [c] >(aLiteral [s] [mean,'Three literal',f5.1]  + 
                       aInferential [s] [mean,'Two inferential',f5.1]) + 
                       readingSkill [s] [mean,'Percentage of children who demonstrate foundational reading skills',f5.1] + 
                       numChildren [s] [validn,'Number of children age 7-14 years',f5.0]) +
          tot [c] > (readCorrect [s] [mean,'Percentage who correctly read 90% of words in a story',f5.1] + 
                       layer [c] >(aLiteral [s] [mean,'Three literal',f5.1]  + 
                       aInferential [s] [mean,'Two inferential',f5.1]) + 
                       readingSkill [s] [mean,'Percentage of children who demonstrate foundational reading skills [1] [2] [3]',f5.1] + 
                       notAvailable [s] [mean,'Percentage of children for whom the reading book was not available in appropriate language',f5.1] + 
                       numChildren [s] [validn,'Number of children age 7-14 years',f5.0])
  /categories var=all empty=exclude missing=exclude
  /slabels position=column
  /titles title=
    "Table LN.4.1: Reading skills"																
    "Percentage of children aged 7-14 who demonstrate foundational reading skills by successfully completing three foundational reading tasks, by sex, " + surveyname
   caption = 
   "[1] MICS indicator LN.22a - Foundational reading and number skills (reading, age 7-14)"																
   "[2] MICS indicator LN.22b - Foundational reading and number skills (reading, age for grade 2/3)"																	
   "[3] MICS indicator LN.22c - Foundational reading and number skills (reading, attending grade 2/3); SDG indicator 4.1.1"
.													

	
* Ctables command in French.  
* ctables
  /format missing = "na" 
  /vlabels variables = numChildren readCorrect aLiteral aInferential readingSkill notAvailable HL4 tot layer
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + $schage [c]
         + $school [c]
         + melevel [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
          hl4 [c] > (readCorrect [s] [mean,'Pourcentage qui a correctement lu 90% des mots d'une histoire',f5.1] + 
                       layer [c] >(aLiteral [s] [mean,' Trois littrales ',f5.1]  + 
                       aInferential [s] [mean,' Deux infrentielles',f5.1]) + 
                       readingSkill [s] [mean,'Pourcentage ayant dmontr des comptences fondamentales en lecture ',f5.1] + 
                       numChildren [s] [validn,'Nombre d'enfants gs de 7-14 ans',f5.0]) +
          tot [c] > (readCorrect [s] [mean,'Pourcentage qui a correctement lu 90% des mots d'une histoire',f5.1] + 
                       layer [c] >( aLiteral [s] [mean,'Trois littrales ',f5.1]  + 
                       aInferential [s] [mean,'Deux infrentielles',f5.1]) + 
                       readingSkill [s] [mean,'Pourcentage ayant dmontr des comptences fondamentales en lecture [1] [2] [3]',f5.1] + 
                       notAvailable [s] [mean,'Pourcentage d''enfants pour lesquels le livre de lecture n'tait pas disponible dans la langue approprie',f5.1] + 
                       numChildren [s] [validn,'Nombre d'enfants gs de 7-14 ans',f5.0])
  /categories var=all empty=exclude missing=exclude
  /slabels position=column
  /titles title=
    "Tableau LN.4.1: Comptences en lecture"																
    "Pourcentage des enfants gs de 7  14 ans qui dmontrent des comptences de base en lecture en accomplissant avec succs trois tches de lecture fondamentales, selon le sexe, " + surveyname
   caption = 
   "[1] Indicateur MICS LN.22a - Comptences de base en Lecture de base et Calcul (reading, age 7-14)"																
   "[2] Indicateur MICS LN.22b - Comptences de base en Lecture de base et Calcul (reading, age for grade 2/3)"																	
   "[3] Indicateur MICS LN.22c - Comptences de base en Lecture de base et Calcul (reading, attending grade 2/3); Indicateur ODD 4.1.1"
     "na: n'est pas applicable".

* Ctables command in Spanish.  
* ctables
  /format missing = "na" 
  /vlabels variables = numChildren readCorrect aLiteral aInferential readingSkill notAvailable HL4 tot layer
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + $schage [c]
         + $school [c]
         + melevel [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
          hl4 [c] > (readCorrect [s] [mean,'Porcentaje que lee correctamente el 90% de las palabras en la historia',f5.1] + 
                       layer [c] >(aLiteral [s] [mean,' Tres literales ',f5.1]  + 
                       aInferential [s] [mean,' Dos inferenciales',f5.1]) + 
                       readingSkill [s] [mean,'Porcentaje que demostr competencias fundacionales de lectura ',f5.1] + 
                       numChildren [s] [validn,'Nmero de nios de 7 a 14 aos',f5.0]) +
          tot [c] > (readCorrect [s] [mean,'Porcentaje que lee correctamente el 90% de las palabras en la historia',f5.1] + 
                       layer [c] >( aLiteral [s] [mean,'Tres literales ',f5.1]  + 
                       aInferential [s] [mean,'Dos inferencialess',f5.1]) + 
                       readingSkill [s] [mean,'Porcentaje que demostr competencias fundacionales de lectura [1] [2] [3]',f5.1] + 
                       notAvailable [s] [mean,'Porcentaje de nios para quienes el libro de lectura no estaba disponible en el idioma apropiado',f5.1] + 
                       numChildren [s] [validn,'Nmero de nios de 7 a 14 aos',f5.0])
  /categories var=all empty=exclude missing=exclude
  /slabels position=column
  /titles title=
    "Tabla LN.4.1: Habilidad de lectura"																
    "Porcentaje de nios de 7 a 14 aos que demuestran competencias fundacionales de lectura al completar con xito tres tareas fundacionales de lectura, por sexo " + surveyname
   caption = 
   "[1] MICS indicador LN.22a - Competencias fundacionales de lectura y aritmtica (lectura, edad 7-14)"																
   "[2] MICS indicador LN.22b - Competencias fundacionales de lectura y aritmtica (lectura, edad para 2/3 grados)"																	
   "[3] MICS indicador LN.22c - Competencias fundacionales de lectura y aritmtica (lectura, asistencia a 2/3 grado); Indicador ODS 4.1.1"
     "na: no aplicable".


new file.
* Encoding: UTF-8.
