* Encoding: windows-1252.

* The table presents three indicators, one of which may require customisation: MICS Indicator LN.22b is measured on children with age for primary grades 2 and 3. 
* Following the standard used throughout the standard LN tables, 
* the indicator is set age age 7 and 8, as children start school at age 6. 
* For example, if primary grade 1 is set at age 7 in a country, this indicator should instead be measured on age group 8-9.

include "surveyname.sps".

get file = 'fs.sav'.

include "CommonVarsFS.sps".

weight by fsweight.

*The denominator includes all children with a completed module (FL28=01).
select if (FL28 = 1).

select if CB3 >=7 and CB3 <=14.

 * Percentage of children who successfully complete:
- A number reading task: All FL23=1
- A number discrimination task: All FL24=1
- An addition task: All FL25=1
- A pattern recognition and completion task: All FL27=1
- Demonstrate foundational numeracy skills: All of the above.

count numberReadTarget = FL23A FL23B FL23C FL23D FL23E FL23F (1).
compute numberRead = 0.
if (numberReadTarget = 6) numberRead = 100.
variable labels numberRead "Percentage of children who successfully completed tasks of: Number reading".

compute numberDiscr  = 0.
*if (FL24A = "7" and FL24B = "24" and FL24C = "58" and FL24D = "67" and FL24E = "154" ) numberDiscr = 100.
if (FL24A = 1 and FL24B = 1 and FL24C = 1  and FL24D = 1 and FL24E = 1) numberDiscr = 100.
variable labels numberDiscr "Percentage of children who successfully completed tasks of: Number discrimination".

compute numberAdd  = 0.
*if (FL25A = "5" and FL25B = "14" and FL25C = "10" and FL25D = "19" and FL25E = "36") numberAdd = 100.
if (FL25A = 1 and FL25B = 1 and FL25C = 1 and FL25D = 1 and FL25E =1) numberAdd = 100.
variable labels numberAdd "Percentage of children who successfully completed tasks of: Addition".

compute numberPattern = 0.
*if (FL27A = "8" and FL27B = "16" and FL27C = "30" and FL27D = "8" and FL27E = "14") numberPattern = 100.
if (FL27A = 1 and FL27B = 1 and FL27C = 1  and FL27D = 1 and FL27E = 1) numberPattern = 100.
variable labels numberPattern "Pattern recognition and completion".

compute numSkill = 0.
if (numberRead = 100 and numberDiscr = 100 and numberAdd = 100 and numberPattern = 100) numSkill = 100.
variable labels numSkill "Percentage of children who demonstrate foundational numeracy skills [1],[2],[3]".
	
compute numChildren = 1.
variable labels numChildren "Number of children age 7-14 years".
value labels numChildren 1 "Number of children age 7-14 years".	

recode CB8A (0=0)(1=10)(2=20)(3,4 = 30) (8,9 = 99)(else = 100) into school.
variable labels school "School attendance".
value lables school
0 "Early childhood education"
10 "Primary"
20 "Lower secondary"
30 "Upper secondary"
99 "DK/Missing"
100 "Out-of-school".

compute schoolAux = school.
if ((CB8A = 1 or CB8A = 2) and CB8B < 97)  schoolAux1 = school + CB8B.
if ((CB8A = 1 or CB8A = 2) and CB8B >= 97) schoolAux1 = 99.
if (CB8A = 1 and (CB8B = 2 or CB8B = 3)) schoolAux2 = 11.1.

value labels schoolAux
0      "Early childhood education"
10    "Primary"
11     "  Grade 1"
11.1  "  Grade 2-3 [3]"
12     "    Grade 2"
13     "    Grade 3"
14     "  Grade 4"
15     "  Grade 5"
16     "  Grade 6"
20    "Lower secondary"
21     "  Grade 1"
22     "  Grade 2"
23     "  Grade 3"
30     "Upper secondary"
99     "DK/Missing"
100   "Out-of-school".

* Define Multiple Response Sets.
mrsets
  /mcgroup name = $school
           label = 'School attendance'
           variables = schoolAux schoolAux1 schoolAux2.

compute schageAux = schage.
if (schage = 7 or schage = 8) schageAux1 = 6.1.

value labels schageAux
 6    "6"
 6.1 "7-8 [2]"
 7    "   7"
 8    "   8"
 9    "9"
 10  "10"
 11  "11"
 12  "12"
 13  "13"
 14  "14".

* Define Multiple Response Sets.
mrsets
  /mcgroup name = $schage
           label = 'Age at beginning of school year'
           variables = schageAux schageAux1.

* Only the total pane includes the column "Percentage of children for whom the reading book was not available in appropriate language". 
* The algorithm for this is: (CB7/ED9=1 and FL9>3) or (CB7/ED9=2 or blank and FL7>3). 
* Note the categories accepted for FL9 and FL7 are those for which no reading book was available). 
* This must be customised in syntax.
compute notAvailable = 0.
if (FL7 <> 1 and FL9 <> 1) notAvailable = 100.
variable labels notAvailable " ".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".	

compute tot = 1.
variable labels tot "".
value labels tot 1 "Total".	

compute layer = 0.
value labels layer 0 "Percentage of children who successfully completed tasks of:".

*  For labels in French uncomment commands below.
* Define Multiple Response Sets.
* mrsets
  /mcgroup name = $school
           label = 'Frquentation scolaire'
           variables = schoolAux schoolAux1 schoolAux2.
* mrsets
  /mcgroup name = $schage
           label = "Age au dbut de l'anne scolaire"
           variables = schageAux schageAux1.
* compute layer = 0.
* variable labels layer "".
* value labels layer 0 "Pourcentage d'enfants ayant accompli avec succs les tches suivantes:".	
* value labels school
0 "Prescolaire"
10 "Primaire"
20 "Secondaire 1er Cycle"
30 "Secondaire 2eme Cycle +"
99 "NSP/Manquant"
100 "En dehors de l'cole".
* value labels schoolAux
0      "Prescolaire"
10    "Primaire"
11     "  Niveau 1"
11.1  "  Niveau 2-3 [3]"
12     "    Niveau 2"
13     "    Niveau 3"
14     "  Niveau 4"
15     "  Niveau 5"
16     "  Niveau 6"
20    "Secondaire 1er Cycle"
21     "  Niveau 1"
22     "  Niveau 2"
23     "  Niveau 3"
30     "Secondaire 2eme Cycle +"
99     "NSP/Manquant"
100   "En dehors de l'cole".

*  For labels in Spanish uncomment commands below.
* Define Multiple Response Sets.
* mrsets
  /mcgroup name = $school
           label = 'Asistencia a la escuela'
           variables = schoolAux schoolAux1 schoolAux2.
* mrsets
  /mcgroup name = $schage
           label = "Edad al inicio del ao escolar"
           variables = schageAux schageAux1.
* compute layer = 0.
* variable labels layer "".
* value labels layer 0 "Porcentaje de nios que completaron con xito tareas de:".	
* value labels school
0 "Educacin de la primera  infancia"
10 "Primaria"
20 "Secundaria baja"
30 "Secundaria alta +"
99 "NS/Ignorado"
100 "Fuera de la escuela".
* value labels schoolAux
0      "Educacin de la primera  infancia"
10    "Primaria"
11     "  Grado 1"
11.1  "  Grado 2-3 [3]"
12     "    Grado 2"
13     "    Grado 3"
14     "  Grado 4"
15     "  Grado 5"
16     "  Grado 6"
20    "Secundaria baj"
21     "  Grado 1"
22     "  Grado 2"
23     "  Grado 3"
30     "Secundaria alta +"
99     "NS/Ignorado"
100   "Fuera de la escuela".
           
* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = layer numChildren numberRead numberDiscr numberAdd numberPattern numSkill HL4 tot
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + $schage [c]
         + $school [c]
         + melevel [c]
         + fsdisability [c]
         + caretakerdis [c]         
         + ethnicity [c]         
         + windex5 [c]
   by
          hl4 [c] > (layer [c] >(numberRead [s] [mean,'Number reading',f5.1] + 
                       numberDiscr [s] [mean,'Number discrimination',f5.1]  + 
                       numberAdd [s] [mean,'Addition',f5.1] + 
                       numberPattern [s] [mean,'Pattern recognition and completion',f5.1]) + 
                       numSkill [s] [mean,'Percentage of children who demonstrate foundational numeracy skills',f5.1] + 
                       numChildren [s] [validn,'Number of children age 7-14 years',f5.0]) +
          tot [c] > (layer [c] >(numberRead [s] [mean,'Number reading',f5.1] + 
                       numberDiscr [s] [mean,'Number discrimination',f5.1]  + 
                       numberAdd [s] [mean,'Addition',f5.1] + 
                       numberPattern [s] [mean,'Pattern recognition and completion',f5.1]) + 
                       numSkill [s] [mean,'Percentage of children who demonstrate foundational numeracy skills [1] [2] [3]',f5.1] + 
                       numChildren [s] [validn,'Number of children age 7-14 years',f5.0])
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column
  /titles title=
    "Table LN.4.2: Numeracy skills"																
    "Percentage of children aged 7-14 who demonstrate foundational numeracy skills by successfully completing three foundational numeracy tasks, by sex, " + surveyname
   caption = 
   "[1] MICS indicator LN.22d - Foundational reading and number skills (numeracy, age 7-14)"																			
   "[2] MICS indicator LN.22e - Foundational reading and number skills (numeracy, age for grade 2/3)"																			
   "[3] MICS indicator LN.22f - Foundational reading and number skills (numeracy, attending grade 2/3); SDG indicator 4.1.1".																																			

   
* Ctables command in French.  
* ctables
  /vlabels variables = numChildren numberRead numberDiscr numberAdd numberPattern numSkill HL4 tot layer
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + $schage [c]
         + $school [c]
         + melevel [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
          hl4 [c] > (layer [c] >(numberRead [s] [mean,'Lecture des nombres',f5.1] + 
                       numberDiscr [s] [mean,'Discrimination des nombres',f5.1]  + 
                       numberAdd [s] [mean,'Addition',f5.1] + 
                       numberPattern [s] [mean,'Reconnaissance et Achvement de modle',f5.1]) + 
                       numSkill [s] [mean,'Pourcentage d''enfants dmontrant des comptences en calcul',f5.1] + 
                       numChildren [s] [validn,'Nombre d''enfants gs de 7-14 ans ',f5.0]) +
          tot [c] > (layer [c] >(numberRead [s] [mean,'Lecture des nombres',f5.1] + 
                       numberDiscr [s] [mean,'Discrimination des nombres',f5.1]  + 
                       numberAdd [s] [mean,'Addition',f5.1] + 
                       numberPattern [s] [mean,'Reconnaissance et Achvement de modle',f5.1]) + 
                       numSkill [s] [mean,"Pourcentage d'enfants dmontrant des comptences en calcul [1] [2] [3]",f5.1] + 
                       numChildren [s] [validn,"Nombre d'enfants gs de 7-14 ans",f5.0])
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column
  /titles title=
    "Tableau LN.4.2: Comptences en calcul"																
    "Pourcentage d''enfants gs de 7  14 ans qui dmontrent des comptences fondamentales en numratie en accomplissant avec succs trois tches fondamentales en numratie, selon le sexe, " + surveyname
   caption = 
   "[1] Indicateur MICS LN.22d - Comptences de base en Lecture de base et Calcul (numeracy, age 7-14)"																			
   "[2] Indicateur MICS LN.22e - Comptences de base en Lecture de base et Calcul (numeracy, age for grade 2/3)"																			
   "[3] Indicateur MICS LN.22f - Comptences de base en Lecture de base et Calcul (numeracy, attending grade 2/3); Indicateur ODD 4.1.1".

* Ctables command in Spanish.  
* ctables
  /vlabels variables = numChildren numberRead numberDiscr numberAdd numberPattern numSkill HL4 tot layer
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + $schage [c]
         + $school [c]
         + melevel [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
          hl4 [c] > (layer [c] >(numberRead [s] [mean,'Lectura de nmeros',f5.1] + 
                       numberDiscr [s] [mean,'Discriminacin de nmeros',f5.1]  + 
                       numberAdd [s] [mean,'Suma',f5.1] + 
                       numberPattern [s] [mean,'Reconocimiento y finalizacin de patrones',f5.1]) + 
                       numSkill [s] [mean,'Porcentaje de nios que demuestran competencias fundacionales de aritmtica',f5.1] + 
                       numChildren [s] [validn,'Nmero de nios de 7 a 14 aos ',f5.0]) +
          tot [c] > (layer [c] >(numberRead [s] [mean,'Lectura de nmeros',f5.1] + 
                       numberDiscr [s] [mean,'Discriminacin de nmeros',f5.1]  + 
                       numberAdd [s] [mean,'Suma',f5.1] + 
                       numberPattern [s] [mean,'Reconocimiento y finalizacin de patrones',f5.1]) + 
                       numSkill [s] [mean,"Porcentaje de nios que demuestran competencias fundacionales de aritmtica [1] [2] [3]",f5.1] + 
                       numChildren [s] [validn,"Nmero de nias de 7 a 14 aos",f5.0])
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column
  /titles title=
    "Tabla LN.4.2: Habilidad numricas"																
    "Porcentaje de nios de 7 a 14 aos que demuestran competencias fundacionales numricas mediante tres tareas bsicas de aritmtica, por sexo, " + surveyname
   caption = 
   "[1] MICS indicador LN.22d - Competencias fundacionales de lectura y aritmtica (aritmtica, edad 7-14)"																			
   "[2] MICS indicador LN.22e - Competencias fundacionales de lectura y aritmtica (aritmtica, edad para 2/3 grado)"																			
   "[3] MICS indicador LN.22f - Competencias fundacionales de lectura y aritmtica (aritmtica, asistencia a 2/3 grado); Indicator ODS 4.1.1".	

new file.
