* Encoding: windows-1252.
 * Households that received social transfers or benefits in the last 3 months: ST4A, ST4B, ST4C, ST4D, or ST4X=100, 101, 102, or 103 or, for any member age 5-24, ED12=1 or ED14=1)

 * Denominators are obtained by weighting the number of households by the number of household members (HH48).
***.


* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file= 'hl.sav'.

sort cases HH1 HH2.

compute EDsupport=0.
if (ED12=1 or ED14=1) EDsupport=1.

aggregate outfile = 'EDsupport.sav'
  /break   = HH1 HH2
  /nEDsupport  = sum(EDsupport).

new file.

get file = 'hh.sav'.

include "CommonVarsHH.sps".

select if (HH46  = 1).

sort cases by HH1 HH2.

match files
  /file = *
  /table = 'EDsupport.sav'
  /by HH1 HH2.

compute hhweightHH48 = HH48*hhweight.
weight by hhweightHH48.

compute Socialtransfer1=0.
if (ST4U$1=1 and ST4N$1<=3) Socialtransfer1=100.
variable labels Socialtransfer1 "Assistance type 1".

compute Socialtransfer2=0.
if (ST4U$2=1 and ST4N$2<=3) Socialtransfer2=100.
variable labels Socialtransfer2 "Assistance type 2".

compute Socialtransfer3=0.
if (ST4U$3=1 and ST4N$3<=3) Socialtransfer3=100.
variable labels Socialtransfer3 "Assistance type 3".

compute SocialtransferPension=0.
if (ST4U$4=1 and ST4N$4<=3) SocialtransferPension=100.
variable labels SocialtransferPension "Any retirement pension	".

compute SocialtransferOther=0.
if (ST4U$5=1 and ST4N$5<=3) SocialtransferOther=100.
variable labels SocialtransferOther "Any other external assistance program".

compute EDsupport=0.
if nEDsupport>0  EDsupport=100.
variable labels EDsupport "School tuition or school related other support for any household member age 5-24 years".

compute any=0.
if (Socialtransfer1=100 or Socialtransfer2=100 or Socialtransfer3=100 or SocialtransferPension=100 or SocialtransferOther=100 or EDsupport=100) any=100.
variable labels any "Any social transfers or benefits [1]".

compute none=0.
if (any=0) none=100.
variable labels none "No social transfers or benefits".

compute layer1 = 0.
variable labels layer1 " ".
value labels layer1 0 "Percentage of household members living in households receiving specific types of support in the last 3 months:".

compute nhh = 1.
variable labels  nhh "Number of household members".
value labels nhh 1 " ".

compute total = 1.
variable labels  total "Total".
value labels total 1 " ".

*  For labels in French uncomment commands below.
* variable labels
     nhh "Nombre de membres du mnage"
	/none "Aucun transfert ou avantage social"	
	/any "Tout transfert ou avantage social [1]"
	/EDsupport "School tuition or school related other support for any household member age 5-24 years"
	/SocialtransferOther "Tout autre programme d'aide extrieure"
	/SocialtransferPension "Toute pension de retraite"
	/Socialtransfer1 "Assistance Type I"
	/Socialtransfer2 "Assistance Type II"
	/Socialtransfer3 "Assistance Type III".
* value labels layer1 0 "Pourcentage des membres du mnage vivant dans des mnages recevant des types spcifiques de soutien au cours des 3 derniers mois:".

*  For labels in Spanish uncomment commands below.
* variable labels
     nhh "Nmero de miembros del hogar"
	/none "Sin transferencias sociales o beneficios"	
	/any "Cualquier transferencia o beneficio social [1]"
	/EDsupport "School tuition or school related other support for any household member age 5-24 years"
	/SocialtransferOther "Cualquier otro programa de asistencia externa"
	/SocialtransferPension "Cualquier pensin de jubilacin"
	/Socialtransfer1 " Asistencia Tipo I"
	/Socialtransfer2 " Asistencia Tipo II"
	/Socialtransfer3 " Asistencia Tipo III".
* value labels layer1 0 "Porcentaje de miembros del hogar que viven en hogares que reciben tipos especficos de apoyo en los ltimos 3 meses:".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = layer1
           display = none
  /table   total [c]
         + HHSEX [c]
         + HH6 [c]
         + HH7 [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c]
   by 
            layer1 [c] > 
           (Socialtransfer1 [s] [mean '' f5.1] 
         + Socialtransfer2 [s] [mean '' f5.1] 
         + Socialtransfer3 [s] [mean '' f5.1] 
         + SocialtransferPension [s] [mean '' f5.1] 
         + SocialtransferOther [s] [mean '' f5.1]
         + EDsupport [s] [mean '' f5.1] )
         + any [s] [mean '' f5.1]
         + none [s] [mean '' f5.1]
         + nhh [s] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title = 
    "Table EQ.2.5: Coverage of social transfers and benefits: All household members"
    "Percentage of household members living in households that received social transfers or benefits in the last 3 months, by type of transfers and benefits, " + surveyname
.
     
* Ctables command in French.  
* ctables
  /vlabels variables = layer1
           display = none
  /table   total [c]
         + HHSEX [c]
         + HH6 [c]
         + HH7 [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c]
   by 
            layer1 [c] > 
           (Socialtransfer1 [s] [mean '' f5.1] 
         + Socialtransfer2 [s] [mean '' f5.1] 
         + Socialtransfer3 [s] [mean '' f5.1] 
         + SocialtransferPension [s] [mean '' f5.1] 
         + SocialtransferOther [s] [mean '' f5.1]
         + EDsupport [s] [mean '' f5.1] )
         + any [s] [mean '' f5.1]
         + none [s] [mean '' f5.1]
         + nhh [s] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title = 
     "Tableau EQ.2.5: Couverture des transferts sociaux et des avantages sociaux: Tous les membres du mnage"
    "Pourcentage des membres du mnage vivant dans des mnages ayant bnfici de transferts sociaux ou d'avantages sociaux au cours des 3 derniers mois, par type de transferts et d'avantages sociaux, " + surveyname
.
	 
     
* Ctables command in Spanish.  
* ctables
  /vlabels variables = layer1
           display = none
  /table   total [c]
         + HHSEX [c]
         + HH6 [c]
         + HH7 [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c]
   by 
            layer1 [c] > 
           (Socialtransfer1 [s] [mean '' f5.1] 
         + Socialtransfer2 [s] [mean '' f5.1] 
         + Socialtransfer3 [s] [mean '' f5.1] 
         + SocialtransferPension [s] [mean '' f5.1] 
         + SocialtransferOther [s] [mean '' f5.1]
         + EDsupport [s] [mean '' f5.1] )
         + any [s] [mean '' f5.1]
         + none [s] [mean '' f5.1]
         + nhh [s] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title = 
    "Tabla EQ.2.5: Cobertura de transferencias y beneficios sociales: Todos los miembros del hogar"
    "Porcentaje de miembros del hogar que viven en hogares que recibieron transferencias o beneficios sociales en los ltimos 3 meses, por tipo de transferencias y beneficios, " + surveyname
.
	 
new file.

erase file "EDsupport.sav".
